#!/usr/bin/env bash
TRPROGRAM=$(printf $1 | tr - _)
cat > $1/src/Makefile.am <<EOF
bin_PROGRAMS = $1
${TRPROGRAM}_SOURCES = main.c \\
       g-hello-world.h g-hello-world-private.h g-hello-world.c g-hello-world.gob \\
       \$(BUILT_SOURCES)
${TRPROGRAM}_CPPFLAGS = \$(DEPS_CFLAGS)
${TRPROGRAM}_LDADD = \$(DEPS_LIBS)
BUILT_SOURCES = g-hello-world.gob.stamp

MAINTAINERCLEANFILES = \$(BUILT_SOURCES)

%.gob.stamp: %.gob
	@GOB2@ --no-touch \$<
	@touch \$@

%.c %.h %-private.h: %.gob
	@GOB2@ $<
EOF
